package com.akamai.ads.sample;

import com.akamai.analytics.trackers.ComscoreTracker;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.ui.media.MediaPlayerController;
import com.akamai.webvtt.captioner.CaptionComponent;

import android.os.Bundle;
import android.app.Activity;
import android.graphics.Color;
import android.view.Menu;
import android.widget.ProgressBar;

// Sample application
// Implements:
// - Events management
// - Playback support for live and vod streams
// - Seeking support 
public class Activity_AlwaysFullScreen extends Activity
{
	// Video Player container object
		private VideoPlayerContainer mVideoPlayerContainer;
		
		// Video Player object
		private VideoPlayerView mVideoPlayer;

		// Control bar component
		private MediaPlayerController mMediaPlayerController;
		
		// Comscore plugin
		private ComscoreTracker mComscoreTracker;
		
		// Captioning plugin
		private CaptionComponent mCaptionComponent;
		
		// Progress bar control
		private ProgressBar mProgressBar;
		
		// Media Asset url
		private final String MEDIA_ASSET_URL = "http://devimages.apple.com/iphone/samples/bipbop/bipbopall.m3u8";
		
		// Android SDK License
		private final String ANDROID_SDK_LICENSE = "BDGwrYmK2CdPurFiGek-gfFAqYtS3W1aTVD_S9s5XmL2U1J_3b5qEuiaH7WOMLszuBjkCei4VjQEw4Fi9UbweA==";
		
	    @Override
	    public void onCreate(Bundle savedInstanceState) {
	        super.onCreate(savedInstanceState);
	        setContentView(R.layout.video_player_fullscreen_layout);
	        
	        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);
	        
	        setupVideoPlayerComponents();
	    }
	    
	    private void setupVideoPlayerComponents()
	    {
	    	mVideoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
	        mVideoPlayerContainer.setMode(VideoPlayerContainer.MODE_AUTOMATIC);
	        mVideoPlayer = mVideoPlayerContainer.getVideoPlayer();
	        mVideoPlayer.setLicense(ANDROID_SDK_LICENSE);  

	        // UI Control bar
	        mMediaPlayerController = (MediaPlayerController) findViewById(R.id.playerControls);
	   
	        // Analytics config
	        mComscoreTracker = new ComscoreTracker();
	        mComscoreTracker.enableReporting(false); // set to false here because we are not configuring Comscore in this example
	        mComscoreTracker.init(this);
	        

	        // Captions
	        mCaptionComponent = (CaptionComponent) findViewById(R.id.captionView);
	        
	        // Components config
	        mMediaPlayerController.setVideoPlayerView(mVideoPlayer);
	        mComscoreTracker.setVideoPlayerView(mVideoPlayer);
	        mCaptionComponent.setVideoPlayerView(mVideoPlayer);

	        // Set this object to listen SDK events and start playing the url
	        mVideoPlayer.setProgressBarControl(mProgressBar);
	        
	        // Play Url
	        mVideoPlayer.playUrl(MEDIA_ASSET_URL);
	    }
	    
	 
	    @Override
	    public boolean onCreateOptionsMenu(Menu menu) {
	        getMenuInflater().inflate(R.menu.main, menu);
	        return true;
	    }

	
		@Override
	    protected void onResume() 
	    {	
			if(mVideoPlayer != null)
				mVideoPlayer.onResume();
			
	        super.onResume();
	    }
		
		@Override
	    protected void onPause() 
	    {	
			if(mVideoPlayer != null)
				mVideoPlayer.onPause();
			
	        super.onPause();
	    }
		

		@Override
	    protected void onDestroy() 
	    {	
			mVideoPlayer.stop();
			mVideoPlayer.onDestroy();
	        super.onDestroy();
	    }
	}

		
